# Generated by roxygen2: do not edit by hand

export(clear_sidra_cache)
export(compute_series_starting_points)
export(compute_starting_points_from_microdata)
export(compute_z_aggregates)
export(fetch_monthly_population)
export(fetch_sidra_rolling_quarters)
export(get_sidra_series_metadata)
export(mensalize_sidra_series)
export(pnadc_apply_periods)
export(pnadc_experimental_periods)
export(pnadc_identify_periods)
export(validate_pnadc)
import(data.table)
importFrom(checkmate,assert_character)
importFrom(checkmate,assert_choice)
importFrom(checkmate,assert_data_frame)
importFrom(checkmate,assert_int)
importFrom(checkmate,assert_logical)
importFrom(checkmate,assert_string)
importFrom(lubridate,ymd)
importFrom(stats,lm)
importFrom(stats,predict)
importFrom(utils,data)
importFrom(utils,head)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
