% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-dates.R
\name{utils-dates}
\alias{utils-dates}
\title{Date Utility Functions}
\description{
Internal helper functions for date calculations.

This file includes:
\itemize{
\item Day of week calculation (dow)
\item ISO 8601 week utilities (Monday-Sunday weeks)
\item IBGE first Saturday calculation for reference weeks
\item Month position calculation for quarter mapping
}
}
\keyword{internal}
